/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import static org.junit.Assert.*;

import java.util.Optional;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.datastructure.Edge;
import de.hft.stuttgart.citydoctor2.datastructure.GmlId;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;
import de.hft.stuttgart.quality.model.RingSelfIntersection;
import de.hft.stuttgart.quality.model.ValidationError;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing.LinearRingType;

public class RingEdgeIntersectionErrorTest {

	@Test
	public void testConvertToQualityAdeDatastructure() {
		LinearRing lr = new LinearRing(LinearRingType.EXTERIOR);
		GmlId id = new GmlId("id");
		lr.setGmlId(id);
		Vertex v1 = new Vertex(1, 2, 3);
		Vertex v2 = new Vertex(4, 5, 6);
		Vertex v3 = new Vertex(7, 8, 9);
		Edge e1 = new Edge(v1, v2);
		Edge e2 = new Edge(v2, v3);

		RingEdgeIntersectionError err = new RingEdgeIntersectionError(lr, e1, e2, v1);
		Optional<ValidationError> optional = err.convertToQualityAdeDatastructure();
		assertTrue(optional.isPresent());
		
		RingSelfIntersection adeErr = (RingSelfIntersection) optional.get();
		assertEquals(id.getGmlString(), adeErr.getLinearRingId());
		assertEquals(1, adeErr.getEdge1().getFrom().getValue().get(0), 0.00001);
		assertEquals(4, adeErr.getEdge1().getTo().getValue().get(0), 0.00001);
		assertEquals(4, adeErr.getEdge2().getFrom().getValue().get(0), 0.00001);
		assertEquals(7, adeErr.getEdge2().getTo().getValue().get(0), 0.00001);
		assertEquals(1, adeErr.getVertex1().getValue().get(0), 0.00001);
	}

}
